@@ -3,3 +3,5 @@ class Configuration:
     COMMUNICATOR_TRACE = False
     TRACE_EXEC_OPTION = False
     TIMER_PULSE = 0.1
+    NOSHOW = False
+    DROP_COMMUNICATOR_INVALIDE_DATA = True
\ No newline at end of file
